@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import zaqarclient
 from zaqarclient import errors
 from zaqarclient.queues import client
 from zaqarclient.tests import base
@@ -24,11 +25,14 @@ class TestClient(base.TestBase):
         version = list(client._CLIENTS.keys())[0]
         cli = client.Client('http://example.com',
                             version, {})
-        self.assertTrue(isinstance(cli,
-                                   client._CLIENTS[version]))
+        self.assertIsInstance(cli,
+                              client._CLIENTS[version])
 
     def test_version_failure(self):
         self.assertRaises(errors.ZaqarError,
                           client.Client,
                           'http://example.org',
                           -1, {})
+
+    def test_module_version(self):
+        self.assertTrue(hasattr(zaqarclient, '__version__'))
