@@ -23,8 +23,6 @@ DEFAULT_QUEUES_API_VERSION = '2'
 API_VERSION_OPTION = 'os_queues_api_version'
 API_NAME = "messaging"
 API_VERSIONS = {
-    "1": "zaqarclient.queues.v1.client.Client",
-    "1.1": "zaqarclient.queues.v1.client.Client",
     "2": "zaqarclient.queues.v2.client.Client",
 }
 
