@@ -14,7 +14,7 @@
 # limitations under the License.
 
 import json
-import mock
+from unittest import mock
 
 from zaqarclient.tests.queues import base
 from zaqarclient.transport import errors
@@ -142,11 +142,15 @@ class QueuesV2SubscriptionUnitTest(base.QueuesTestBase):
                                'id': '568afabb508f153573f6a56f',
                                'subscriber': 'http://trigger.me',
                                'ttl': 3600,
+                               'age': 1800,
+                               'confirmed': False,
                                'options': {}},
                               {'source': 'beijing',
                                'id': '568afabb508f153573f6a56x',
                                'subscriber': 'http://trigger.you',
                                'ttl': 7200,
+                               'age': 2309,
+                               'confirmed': True,
                                'options': {'oh stop': 'triggering'}}]}
 
         with mock.patch.object(self.transport, 'send',
@@ -180,8 +184,6 @@ class QueuesV2SubscriptionFunctionalTest(base.QueuesTestBase):
     def setUp(self):
         super(QueuesV2SubscriptionFunctionalTest, self).setUp()
 
-        # TODO(flwang): Now there is a bug(#1529168) for the subscription TTL,
-        # so we will add a test case for TTL after the bug fixed.
         self.queue_name = 'beijing'
         queue = self.client.queue(self.queue_name, force_create=True)
         self.addCleanup(queue.delete)
